==> untangled-client-0.6.1-20161215.183334-3.jar: public/js/cards/out/untangled_spec/stub.js <==
// Compiled by ClojureScript 1.9.293 {}
goog.provide('untangled_spec.stub');
goog.require('cljs.core');
untangled_spec.stub.make_step = (function untangled_spec$stub$make_step(stub,times,literals){
return new cljs.core.PersistentArrayMap(null, 4, [new cljs.core.Keyword(null,"stub","stub",1339145807),stub,new cljs.core.Keyword(null,"times","times",1671571467),times,new cljs.core.Keyword(null,"ncalled","ncalled",-112615355),(0),new cljs.core.Keyword(null,"literals","literals",-427821498),literals], null);
});
untangled_spec.stub.make_script = (function untangled_spec$stub$make_script(function$,steps){
return cljs.core.atom.call(null,new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"function","function",-2127255473),function$,new cljs.core.Keyword(null,"steps","steps",-128433302),steps], null));
});
untangled_spec.stub.increment_script_call_count = (function untangled_spec$stub$increment_script_call_count(script_atom,step){
return cljs.core.swap_BANG_.call(null,script_atom,(function (m){
return cljs.core.update_in.call(null,m,new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"steps","steps",-128433302),step,new cljs.core.Keyword(null,"ncalled","ncalled",-112615355)], null),cljs.core.inc);
}));
});
untangled_spec.stub.step_complete = (function untangled_spec$stub$step_complete(script_atom,step){
var ncalled = cljs.core.get_in.call(null,cljs.core.deref.call(null,script_atom),new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"steps","steps",-128433302),step,new cljs.core.Keyword(null,"ncalled","ncalled",-112615355)], null));
var target_times = cljs.core.get_in.call(null,cljs.core.deref.call(null,script_atom),new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"steps","steps",-128433302),step,new cljs.core.Keyword(null,"times","times",1671571467)], null));
return cljs.core._EQ_.call(null,ncalled,target_times);
});
untangled_spec.stub.check_matching = (function untangled_spec$stub$check_matching(arg,_QMARK_literal){
var G__55752 = (((_QMARK_literal instanceof cljs.core.Keyword))?_QMARK_literal.fqn:null);
switch (G__55752) {
case "untangled-spec.provided/any":
return true;

break;
default:
return cljs.core._EQ_.call(null,arg,_QMARK_literal);

}
});
untangled_spec.stub.scripted_stub = (function untangled_spec$stub$scripted_stub(script_atom){
var step = cljs.core.atom.call(null,(0));
return ((function (step){
return (function() { 
var G__55760__delegate = function (args){
var target_function = new cljs.core.Keyword(null,"function","function",-2127255473).cljs$core$IFn$_invoke$arity$1(cljs.core.deref.call(null,script_atom));
var max_calls = cljs.core.count.call(null,new cljs.core.Keyword(null,"steps","steps",-128433302).cljs$core$IFn$_invoke$arity$1(cljs.core.deref.call(null,script_atom)));
if((cljs.core.deref.call(null,step) < max_calls)){
var map__55757 = cljs.core.nth.call(null,new cljs.core.Keyword(null,"steps","steps",-128433302).cljs$core$IFn$_invoke$arity$1(cljs.core.deref.call(null,script_atom)),cljs.core.deref.call(null,step));
var map__55757__$1 = ((((!((map__55757 == null)))?((((map__55757.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__55757.cljs$core$ISeq$)))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__55757):map__55757);
var stub = cljs.core.get.call(null,map__55757__$1,new cljs.core.Keyword(null,"stub","stub",1339145807));
var literals = cljs.core.get.call(null,map__55757__$1,new cljs.core.Keyword(null,"literals","literals",-427821498));
if((cljs.core._EQ_.call(null,cljs.core.count.call(null,literals),cljs.core.count.call(null,args))) && (cljs.core.every_QMARK_.call(null,cljs.core.true_QMARK_,cljs.core.map.call(null,untangled_spec.stub.check_matching,args,literals)))){
} else {
throw cljs.core.ex_info.call(null,[cljs.core.str(target_function),cljs.core.str(" was called with wrong arguments")].join(''),cljs.core.PersistentArrayMap.EMPTY);
}

try{return cljs.core.apply.call(null,stub,args);
}catch (e55759){if((e55759 instanceof Object)){
var e = e55759;
throw e;
} else {
throw e55759;

}
}finally {untangled_spec.stub.increment_script_call_count.call(null,script_atom,cljs.core.deref.call(null,step));

if(cljs.core.truth_(untangled_spec.stub.step_complete.call(null,script_atom,cljs.core.deref.call(null,step)))){
cljs.core.swap_BANG_.call(null,step,cljs.core.inc);
} else {
}
}} else {
throw cljs.core.ex_info.call(null,[cljs.core.str("VERIFY ERROR: "),cljs.core.str(target_function),cljs.core.str(" was called too many times!")].join(''),new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword("untangled-spec.stub","verify-error","untangled-spec.stub/verify-error",700017705),true,new cljs.core.Keyword(null,"max-calls","max-calls",605342920),max_calls], null));
}
};
var G__55760 = function (var_args){
var args = null;
if (arguments.length > 0) {
var G__55761__i = 0, G__55761__a = new Array(arguments.length -  0);
while (G__55761__i < G__55761__a.length) {G__55761__a[G__55761__i] = arguments[G__55761__i + 0]; ++G__55761__i;}
  args = new cljs.core.IndexedSeq(G__55761__a,0);
} 
return G__55760__delegate.call(this,args);};
G__55760.cljs$lang$maxFixedArity = 0;
G__55760.cljs$lang$applyTo = (function (arglist__55762){
var args = cljs.core.seq(arglist__55762);
return G__55760__delegate(args);
});
G__55760.cljs$core$IFn$_invoke$arity$variadic = G__55760__delegate;
return G__55760;
})()
;
;})(step))
});
/**
 * argument step contains keys:
 * - :ncalled, actual number of times called
 * - :times, expected number of times called
 */
untangled_spec.stub.validate_step_counts = (function untangled_spec$stub$validate_step_counts(errors,step){
return cljs.core.conj.call(null,errors,(((cljs.core._EQ_.call(null,new cljs.core.Keyword(null,"ncalled","ncalled",-112615355).cljs$core$IFn$_invoke$arity$1(step),new cljs.core.Keyword(null,"times","times",1671571467).cljs$core$IFn$_invoke$arity$1(step))) || ((cljs.core._EQ_.call(null,new cljs.core.Keyword(null,"times","times",1671571467).cljs$core$IFn$_invoke$arity$1(step),new cljs.core.Keyword(null,"many","many",1092119164))) && ((new cljs.core.Keyword(null,"ncalled","ncalled",-112615355).cljs$core$IFn$_invoke$arity$1(step) > (0)))))?new cljs.core.Keyword(null,"ok","ok",967785236):new cljs.core.Keyword(null,"error","error",-978969032)));
});
untangled_spec.stub.validate_target_function_counts = (function untangled_spec$stub$validate_target_function_counts(script_atoms){
var atoms = script_atoms;
while(true){
if(cljs.core.truth_(cljs.core.not_empty.call(null,atoms))){
var function$ = cljs.core.deref.call(null,cljs.core.first.call(null,atoms));
var count_results = cljs.core.reduce.call(null,untangled_spec.stub.validate_step_counts,cljs.core.PersistentVector.EMPTY,new cljs.core.Keyword(null,"steps","steps",-128433302).cljs$core$IFn$_invoke$arity$1(function$));
var errors_QMARK_ = cljs.core.some.call(null,((function (atoms,function$,count_results){
return (function (p1__55763_SHARP_){
return cljs.core._EQ_.call(null,new cljs.core.Keyword(null,"error","error",-978969032),p1__55763_SHARP_);
});})(atoms,function$,count_results))
,count_results);
if(cljs.core.truth_(errors_QMARK_)){
throw cljs.core.ex_info.call(null,[cljs.core.str("VERIFY ERROR: "),cljs.core.str(new cljs.core.Keyword(null,"function","function",-2127255473).cljs$core$IFn$_invoke$arity$1(function$)),cljs.core.str(" was not called as many times as specified")].join(''),new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword("untangled-spec.stub","verify-error","untangled-spec.stub/verify-error",700017705),true], null));
} else {
}

var G__55764 = cljs.core.rest.call(null,atoms);
atoms = G__55764;
continue;
} else {
return null;
}
break;
}
});

//# sourceMappingURL=stub.js.map?rel=1481754427396

==> untangled-client-0.7.0-20170207.224453-1.jar: public/js/cards/out/untangled_spec/stub.js <==
// Compiled by ClojureScript 1.9.456 {}
goog.provide('untangled_spec.stub');
goog.require('cljs.core');
untangled_spec.stub.make_step = (function untangled_spec$stub$make_step(stub,times,literals){
return new cljs.core.PersistentArrayMap(null, 4, [new cljs.core.Keyword(null,"stub","stub",1339145807),stub,new cljs.core.Keyword(null,"times","times",1671571467),times,new cljs.core.Keyword(null,"ncalled","ncalled",-112615355),(0),new cljs.core.Keyword(null,"literals","literals",-427821498),literals], null);
});
untangled_spec.stub.make_script = (function untangled_spec$stub$make_script(function$,steps){
return cljs.core.atom.call(null,new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"function","function",-2127255473),function$,new cljs.core.Keyword(null,"steps","steps",-128433302),steps], null));
});
untangled_spec.stub.increment_script_call_count = (function untangled_spec$stub$increment_script_call_count(script_atom,step){
return cljs.core.swap_BANG_.call(null,script_atom,(function (m){
return cljs.core.update_in.call(null,m,new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"steps","steps",-128433302),step,new cljs.core.Keyword(null,"ncalled","ncalled",-112615355)], null),cljs.core.inc);
}));
});
untangled_spec.stub.step_complete = (function untangled_spec$stub$step_complete(script_atom,step){
var ncalled = cljs.core.get_in.call(null,cljs.core.deref.call(null,script_atom),new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"steps","steps",-128433302),step,new cljs.core.Keyword(null,"ncalled","ncalled",-112615355)], null));
var target_times = cljs.core.get_in.call(null,cljs.core.deref.call(null,script_atom),new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"steps","steps",-128433302),step,new cljs.core.Keyword(null,"times","times",1671571467)], null));
return cljs.core._EQ_.call(null,ncalled,target_times);
});
untangled_spec.stub.check_matching = (function untangled_spec$stub$check_matching(arg,_QMARK_literal){
var G__56442 = (((_QMARK_literal instanceof cljs.core.Keyword))?_QMARK_literal.fqn:null);
switch (G__56442) {
case "untangled-spec.provided/any":
return true;

break;
default:
return cljs.core._EQ_.call(null,arg,_QMARK_literal);

}
});
untangled_spec.stub.scripted_stub = (function untangled_spec$stub$scripted_stub(script_atom){
var step = cljs.core.atom.call(null,(0));
return ((function (step){
return (function() { 
var G__56450__delegate = function (args){
var target_function = new cljs.core.Keyword(null,"function","function",-2127255473).cljs$core$IFn$_invoke$arity$1(cljs.core.deref.call(null,script_atom));
var max_calls = cljs.core.count.call(null,new cljs.core.Keyword(null,"steps","steps",-128433302).cljs$core$IFn$_invoke$arity$1(cljs.core.deref.call(null,script_atom)));
if((cljs.core.deref.call(null,step) < max_calls)){
var map__56447 = cljs.core.nth.call(null,new cljs.core.Keyword(null,"steps","steps",-128433302).cljs$core$IFn$_invoke$arity$1(cljs.core.deref.call(null,script_atom)),cljs.core.deref.call(null,step));
var map__56447__$1 = ((((!((map__56447 == null)))?((((map__56447.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__56447.cljs$core$ISeq$)))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__56447):map__56447);
var stub = cljs.core.get.call(null,map__56447__$1,new cljs.core.Keyword(null,"stub","stub",1339145807));
var literals = cljs.core.get.call(null,map__56447__$1,new cljs.core.Keyword(null,"literals","literals",-427821498));
if((cljs.core._EQ_.call(null,cljs.core.count.call(null,literals),cljs.core.count.call(null,args))) && (cljs.core.every_QMARK_.call(null,cljs.core.true_QMARK_,cljs.core.map.call(null,untangled_spec.stub.check_matching,args,literals)))){
} else {
throw cljs.core.ex_info.call(null,[cljs.core.str.cljs$core$IFn$_invoke$arity$1(target_function),cljs.core.str.cljs$core$IFn$_invoke$arity$1(" was called with wrong arguments")].join(''),cljs.core.PersistentArrayMap.EMPTY);
}

try{return cljs.core.apply.call(null,stub,args);
}catch (e56449){if((e56449 instanceof Object)){
var e = e56449;
throw e;
} else {
throw e56449;

}
}finally {untangled_spec.stub.increment_script_call_count.call(null,script_atom,cljs.core.deref.call(null,step));

if(cljs.core.truth_(untangled_spec.stub.step_complete.call(null,script_atom,cljs.core.deref.call(null,step)))){
cljs.core.swap_BANG_.call(null,step,cljs.core.inc);
} else {
}
}} else {
throw cljs.core.ex_info.call(null,[cljs.core.str.cljs$core$IFn$_invoke$arity$1("VERIFY ERROR: "),cljs.core.str.cljs$core$IFn$_invoke$arity$1(target_function),cljs.core.str.cljs$core$IFn$_invoke$arity$1(" was called too many times!")].join(''),new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword("untangled-spec.stub","verify-error","untangled-spec.stub/verify-error",700017705),true,new cljs.core.Keyword(null,"max-calls","max-calls",605342920),max_calls], null));
}
};
var G__56450 = function (var_args){
var args = null;
if (arguments.length > 0) {
var G__56451__i = 0, G__56451__a = new Array(arguments.length -  0);
while (G__56451__i < G__56451__a.length) {G__56451__a[G__56451__i] = arguments[G__56451__i + 0]; ++G__56451__i;}
  args = new cljs.core.IndexedSeq(G__56451__a,0);
} 
return G__56450__delegate.call(this,args);};
G__56450.cljs$lang$maxFixedArity = 0;
G__56450.cljs$lang$applyTo = (function (arglist__56452){
var args = cljs.core.seq(arglist__56452);
return G__56450__delegate(args);
});
G__56450.cljs$core$IFn$_invoke$arity$variadic = G__56450__delegate;
return G__56450;
})()
;
;})(step))
});
/**
 * argument step contains keys:
 * - :ncalled, actual number of times called
 * - :times, expected number of times called
 */
untangled_spec.stub.validate_step_counts = (function untangled_spec$stub$validate_step_counts(errors,step){
return cljs.core.conj.call(null,errors,(((cljs.core._EQ_.call(null,new cljs.core.Keyword(null,"ncalled","ncalled",-112615355).cljs$core$IFn$_invoke$arity$1(step),new cljs.core.Keyword(null,"times","times",1671571467).cljs$core$IFn$_invoke$arity$1(step))) || ((cljs.core._EQ_.call(null,new cljs.core.Keyword(null,"times","times",1671571467).cljs$core$IFn$_invoke$arity$1(step),new cljs.core.Keyword(null,"many","many",1092119164))) && ((new cljs.core.Keyword(null,"ncalled","ncalled",-112615355).cljs$core$IFn$_invoke$arity$1(step) > (0)))))?new cljs.core.Keyword(null,"ok","ok",967785236):new cljs.core.Keyword(null,"error","error",-978969032)));
});
untangled_spec.stub.validate_target_function_counts = (function untangled_spec$stub$validate_target_function_counts(script_atoms){
var atoms = script_atoms;
while(true){
if(cljs.core.truth_(cljs.core.not_empty.call(null,atoms))){
var function$ = cljs.core.deref.call(null,cljs.core.first.call(null,atoms));
var count_results = cljs.core.reduce.call(null,untangled_spec.stub.validate_step_counts,cljs.core.PersistentVector.EMPTY,new cljs.core.Keyword(null,"steps","steps",-128433302).cljs$core$IFn$_invoke$arity$1(function$));
var errors_QMARK_ = cljs.core.some.call(null,((function (atoms,function$,count_results){
return (function (p1__56453_SHARP_){
return cljs.core._EQ_.call(null,new cljs.core.Keyword(null,"error","error",-978969032),p1__56453_SHARP_);
});})(atoms,function$,count_results))
,count_results);
if(cljs.core.truth_(errors_QMARK_)){
throw cljs.core.ex_info.call(null,[cljs.core.str.cljs$core$IFn$_invoke$arity$1("VERIFY ERROR: "),cljs.core.str.cljs$core$IFn$_invoke$arity$1(new cljs.core.Keyword(null,"function","function",-2127255473).cljs$core$IFn$_invoke$arity$1(function$)),cljs.core.str.cljs$core$IFn$_invoke$arity$1(" was not called as many times as specified")].join(''),new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword("untangled-spec.stub","verify-error","untangled-spec.stub/verify-error",700017705),true], null));
} else {
}

var G__56454 = cljs.core.rest.call(null,atoms);
atoms = G__56454;
continue;
} else {
return null;
}
break;
}
});

//# sourceMappingURL=stub.js.map?rel=1486495668293
